@@ -26,9 +26,9 @@ my $redis = AnyEvent::Redis::RipeRedis->new(
 $redis->eval_cached( 'return { KEYS[1], KEYS[2], ARGV[1], ARGV[2] }',
     2, 'key1', 'key2', 'first', 'second',
   { on_done => sub {
-      my $reply = shift;
+      my $data = shift;
 
-      foreach my $val ( @{$reply}  ) {
+      foreach my $val ( @{$data}  ) {
         print "$val\n";
       }
 
