@@ -30,16 +30,17 @@ $timer = AE::timer( 0, 1,
   sub {
     $redis->incr( 'foo',
       sub {
-        my $reply   = shift;
-        my $err_msg = shift;
+        my $data = shift;
+
+        if ( defined $_[0] ) {
+          my $err_msg = shift;
 
-        if ( defined $err_msg ) {
           warn $err_msg;
 
           return;
         }
 
-        print "$reply\n";
+        print "$data\n";
       },
     );
   },
@@ -50,7 +51,7 @@ my $on_signal = sub {
   $cv->send();
 };
 
-my $int_w = AE::signal( INT => $on_signal );
+my $int_w  = AE::signal( INT  => $on_signal );
 my $term_w = AE::signal( TERM => $on_signal );
 
 $cv->recv();
